@@ -4,6 +4,7 @@ from typing import Type
 
 from airflow.operators.bash import BashOperator
 
+from dkist_processing_core.resource_queue import ResourceQueue
 from dkist_processing_core.task import TaskBase
 
 
@@ -20,6 +21,7 @@ class Node:
         workflow_version: str,
         workflow_package: str,
         task: task_type_hint,
+        resource_queue: ResourceQueue,
         upstreams: upstreams_type_hint = None,
     ):
         """Node setup."""
@@ -40,6 +42,7 @@ class Node:
         self.task = task
         self.workflow_package = workflow_package
         self.upstreams = upstreams
+        self.resource_queue = resource_queue
 
     @property
     def operator(self) -> BashOperator:
@@ -65,6 +68,7 @@ class Node:
         task_name='{self.task.__name__}'
     ),
     owner="DKIST Data Center",
+    queue="{self.resource_queue.value}",
 )
 """
 
@@ -95,6 +99,7 @@ echo $NOMAD_HOST_ADDR_worker
 echo NOMAD_ALLOC_NAME
 echo $NOMAD_ALLOC_NAME
 echo Host Python Environment i.e. system-site-packages
+python3 -m pip install --upgrade pip
 pip list
 echo Creating Virtual Environment
 python3 -m venv --system-site-packages .task_venv
@@ -129,3 +134,11 @@ python -m pip install {repo_name}=={version}"""
 with {self.task.__name__}(recipe_run_id={{{{dag_run.conf['recipe_run_id']}}}}, workflow_name='{self.workflow_name}', workflow_version='{self.workflow_version}') as task:
     task()
 """
+
+    def __repr__(self):
+        """Render node instantiation as a string."""
+        return f"Node(workflow_name={self.workflow_name}, workflow_version={self.workflow_version}, workflow_package={self.workflow_package}, task={self.task!r}, upstreams={self.upstreams}, queue={self.resource_queue!r})"
+
+    def __str__(self):
+        """Render node instance as a string."""
+        return repr(self)
