@@ -3,10 +3,6 @@ import importlib
 from pathlib import Path
 from shutil import rmtree
 from types import ModuleType
-from typing import Any
-from typing import List
-from typing import Optional
-from typing import Union
 
 from airflow.models import DAG
 
@@ -16,7 +12,7 @@ from dkist_processing_core import Workflow
 __all__ = ["validate_workflows", "export"]
 
 
-def validate_workflows(workflow_package: ModuleType, export_path: Optional[Path] = None) -> None:
+def validate_workflows(workflow_package: ModuleType, export_path: Path | None = None) -> None:
     """Validate that workflow engine (airflow) objects are acyclic and that exported workflows compile."""
     # configure export path.  Clean up after if export path not provided
     rm_export_path_after_test = not bool(export_path)
@@ -32,16 +28,16 @@ def validate_workflows(workflow_package: ModuleType, export_path: Optional[Path]
     _validate_dags(dags)
 
 
-def export(workflow_package: ModuleType, export_path: Optional[Union[str, Path]] = None) -> None:
+def export(workflow_package: ModuleType, export_path: str | Path | None = None) -> None:
     """Export workflows for deployment."""
     [w.export(export_path) for w in _extract_workflows_from_package(workflow_package)]
 
 
-def _extract_workflows_from_package(workflow_package: ModuleType) -> List[Workflow]:
+def _extract_workflows_from_package(workflow_package: ModuleType) -> list[Workflow]:
     return _extract_objects_from_package_by_type(workflow_package, Workflow)
 
 
-def _extract_objects_from_package_by_type(package: ModuleType, object_type: type) -> List[Any]:
+def _extract_objects_from_package_by_type(package: ModuleType, object_type: type) -> list:
     modules = _parse_unprotected_modules_names_from_package(package)
     objects = []
     for module in modules:
@@ -50,12 +46,12 @@ def _extract_objects_from_package_by_type(package: ModuleType, object_type: type
     return objects
 
 
-def _parse_unprotected_modules_names_from_package(package: ModuleType) -> List[str]:
+def _parse_unprotected_modules_names_from_package(package: ModuleType) -> list[str]:
     package_path = Path(package.__path__[0])
     return [m.stem for m in package_path.glob("[!_]*.py")]
 
 
-def _validate_dags(dags: List[DAG]) -> None:
+def _validate_dags(dags: list[DAG]) -> None:
     """Validate dags by ensuring they can be traversed without cycles and are syntactically correct."""
     for d in dags:
         try:
@@ -64,7 +60,7 @@ def _validate_dags(dags: List[DAG]) -> None:
             raise SyntaxError(f"DAG {d.dag_id} malformed.  Parsing resulted in error: {e=}") from e
 
 
-def _validate_workflows(workflows: List[Workflow], export_path: Path) -> None:
+def _validate_workflows(workflows: list[Workflow], export_path: Path) -> None:
     """Validate workflows by ensuring their exported version compiles as python and that there is at least one node."""
     for w in workflows:
         try:
