@@ -6,6 +6,7 @@ from typing import Any
 
 import pytest
 
+from dkist_processing_core import ResourceQueue
 from dkist_processing_core import TaskBase
 from dkist_processing_core import Workflow
 from dkist_processing_core._node import Node
@@ -104,8 +105,16 @@ def workflow_tasks(task_subclass) -> list[task_type_hint]:
     return [TaskA, TaskB, TaskC, TaskD]
 
 
+@pytest.fixture(params=["default", "non_default"])
+def queue_name(request):
+    """Name of the queue on the Node"""
+    if request.param == "default":
+        return ResourceQueue.DEFAULT
+    return ResourceQueue.HIGH_MEMORY
+
+
 @pytest.fixture(params=["0_upstream", "1_upstream", "2_upstream"])
-def node(workflow_tasks, request) -> tuple[Node, task_type_hint, Any, str, str]:
+def node(workflow_tasks, request, queue_name) -> tuple[Node, task_type_hint, Any, str, str]:
     """Node instance and its component parts."""
     version = "V6-123"
     name = f"{request.param}_{version}"
@@ -124,6 +133,7 @@ def node(workflow_tasks, request) -> tuple[Node, task_type_hint, Any, str, str]:
             workflow_package=package,
             task=TaskA,
             upstreams=upstream[0],
+            resource_queue=queue_name,
         ),
         TaskA,
         upstream[1],
