@@ -46,10 +46,10 @@ def env_vars(request):
 def test_recipe_run_failure_producer_factory(env_vars):
     """
     Given: recipe_run_failure_producer_factory.
-    When: retrieving an producer from the factory.
+    When: retrieving a producer from the factory.
     Then: it is an instance of a talus.DurableBlockingProducerWrapper.
     """
-    with pytest.raises(pika.exceptions.AMQPConnectionError):
+    with pytest.raises(pika.exceptions.AMQPError):
         recipe_run_failure_message_producer_factory().__enter__()
 
 
