@@ -1,16 +1,30 @@
 """Tests of the _node.py module."""
 import subprocess
 from subprocess import CalledProcessError
+from typing import Callable
 
 import pytest
 from airflow.operators.bash import BashOperator
 from jinja2 import Template
 
+from dkist_processing_core import ResourceQueue
 from dkist_processing_core._node import Node
 from dkist_processing_core.tests.task_example import Task
 
 
-def test_nodes(node, fake_producer_factory):
+@pytest.fixture()
+def single_node() -> Node:
+    """A single Node instance."""
+    return Node(
+        workflow_name="test_node",
+        workflow_version="v1",
+        workflow_package=__package__,
+        task=Task,
+        resource_queue=ResourceQueue.DEFAULT,
+    )
+
+
+def test_nodes(node, fake_producer_factory, queue_name):
     """
     Given: Workflow tasks to initialize a Node.
     When: Initializing the Node with valid task and upstreams.
@@ -29,6 +43,7 @@ def test_nodes(node, fake_producer_factory):
     assert node.upstreams == upstream
     assert node.task == task
     assert node.workflow_version == version
+    assert node.resource_queue == queue_name
 
 
 def test_node_bash_template_return_0(node):
@@ -55,20 +70,14 @@ def test_node_bash_template_return_1(node):
         subprocess.run(node._bash_template(cmd), shell=True, check=True)
 
 
-def test_node_python():
+def test_node_python(single_node):
     """
     Given: Python jinja rendered with dag run data from a node instance.
     When: parsing the python call.
     Then: no exceptions raised.
     """
     # Given
-    node = Node(
-        workflow_name="test_node_python",
-        workflow_version="v1",
-        workflow_package=__package__,
-        task=Task,
-    )
-    code_template = Template(node._python)
+    code_template = Template(single_node._python)
 
     class RenderData:
         def __init__(self):
@@ -114,3 +123,20 @@ def test_invalid_node(task_subclass):
             task=GoodTask,
             upstreams=[GoodTask, BadTask],
         )
+
+
+@pytest.mark.parametrize(
+    "func, attr",
+    [
+        pytest.param(repr, "__repr__", id="repr"),
+        pytest.param(str, "__str__", id="str"),
+    ],
+)
+def test_node_dunder(single_node, func: Callable, attr: str):
+    """
+    Given: Node instance
+    When: retrieving dunder method that should be implemented.
+    Then: It is implemented.
+    """
+    assert getattr(single_node, attr, None)
+    assert func(single_node)
