@@ -5,6 +5,7 @@ from typing import Callable
 import pytest
 from airflow import DAG
 
+from dkist_processing_core import ResourceQueue
 from dkist_processing_core import Workflow
 
 
@@ -42,7 +43,14 @@ def test_workflow_metadata(workflow):
     )
 
 
-def test_workflow_add_node(workflow_tasks, workflow):
+@pytest.mark.parametrize(
+    "queue",
+    [
+        pytest.param(None, id="None"),
+        pytest.param(ResourceQueue.HIGH_MEMORY, id="Specified"),
+    ],
+)
+def test_workflow_add_node(workflow_tasks, workflow, queue):
     """
     Given: A set of tasks and a workflow instance.
     When: Adding the tasks to the workflow in the
@@ -79,7 +87,7 @@ def test_workflow_add_node(workflow_tasks, workflow):
         },
     }
     for task, upstream in task_definitions.items():
-        workflow_instance.add_node(task, upstreams=upstream)
+        workflow_instance.add_node(task, resource_queue=queue, upstreams=upstream)
 
     dag = workflow_instance.load()
     assert dag.task_count == 4
@@ -115,9 +123,9 @@ def test_invalid_workflow_add_node(workflow):
         pytest.param(str, "__str__", id="str"),
     ],
 )
-def test_tag_db_dunder(workflow, func: Callable, attr):
+def test_workflow_dunder(workflow, func: Callable, attr):
     """
-    Given: Connection to a tag database.
+    Given: workflow instance.
     When: retrieving dunder method that should be implemented.
     Then: It is implemented.
     """
