@@ -6,13 +6,14 @@ from pathlib import Path
 
 from airflow import DAG
 
+from dkist_processing_core import ResourceQueue
 from dkist_processing_core._node import Node
 from dkist_processing_core._node import task_type_hint
 from dkist_processing_core._node import upstreams_type_hint
 
 __all__ = ["Workflow"]
 
-MAXIMUM_ALLOWED_WORKFLOW_NAME_LENGTH = 50
+MAXIMUM_ALLOWED_WORKFLOW_NAME_LENGTH = 100
 
 
 class Workflow:
@@ -150,10 +151,11 @@ class Workflow:
 
     @property
     def _dag_definition(self) -> str:
-        return f"DAG(dag_id='{self._dag_name}', start_date=days_ago(2), schedule_interval=None, catchup=False, tags={self._dag_tags})"
+
+        return f"DAG(dag_id='{self._dag_name}', start_date=pendulum.today('UTC').add(days=-2), schedule=None, catchup=False, tags={self._dag_tags})"
 
     def _initialize_local_dag(self) -> DAG:
-        from airflow.utils.dates import days_ago
+        import pendulum
 
         return eval(self._dag_definition)
 
@@ -161,13 +163,18 @@ class Workflow:
         self,
         task: task_type_hint,
         upstreams: upstreams_type_hint = None,
+        resource_queue: ResourceQueue | None = None,
     ) -> None:
         """Add a node and edges from that node to the workflow."""
+        if resource_queue is None:
+            resource_queue = ResourceQueue.DEFAULT
+
         node = Node(
             workflow_name=self.workflow_name,
             workflow_version=self.workflow_version,
             workflow_package=self.workflow_package,
             task=task,
+            resource_queue=resource_queue,
             upstreams=upstreams,
         )
         self.nodes.append(node)
@@ -212,7 +219,7 @@ class Workflow:
             "",
             "from airflow import DAG",
             "from airflow.operators.bash import BashOperator",
-            "from airflow.utils.dates import days_ago",
+            "import pendulum",
             "",
             "from dkist_processing_core._failure_callback import chat_ops_notification",
             "",
